/*!
 * \file  AppData.m
 *       Define constants, enums, and structs for data model of BuddhaCounter project
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 06/02/10                                    */
/***************************************************************************/

/**************************************************************************** 
 * COMPILATION OPTIONS
 ***************************************************************************/

//=========================================================================== 
// HEADER FILES
//=========================================================================== 
#import "AppModel.h"

//=========================================================================== 
// TYPEDEFs & MACROs
//=========================================================================== 

//=========================================================================== 
// CLASS IMPLEMENTATION
//===========================================================================
@implementation Book (Utility)

//---------------------------------------------------------------------------
+ (NSString*)categoryInString:(int)nCategory
{
    NSArray *pCategoryArray = [NSArray arrayWithObjects:
        NSLocalizedString(@"Buddhas", @"category of buddhas"),
        NSLocalizedString(@"Sutras",  @"category of sutras"),
        NSLocalizedString(@"Others",  @"category that are not in Verses and Sutras"),
        nil];
    return [pCategoryArray objectAtIndex:nCategory];
}

//---------------------------------------------------------------------------
+ (NSString*)categoryForTitle:(int)nCategory
{
    NSArray *pCategoryArray = [NSArray arrayWithObjects:
        NSLocalizedString(@"Buddha", @"title of buddhas"),
        NSLocalizedString(@"Sutra",  @"title of sutras"),
        NSLocalizedString(@"Other",  @"title that are not in Verses and Sutras"),
        nil];
    return [pCategoryArray objectAtIndex:nCategory];
}

//---------------------------------------------------------------------------
- (NSString*)categoryInString
{
    return [Book categoryInString:[self.category intValue]];
}

//---------------------------------------------------------------------------
- (void)defaultSettingWithCategory:(NSNumber*)pCategory 
                             title:(NSString*)psTitle
                       countTarget:(NSNumber*)pCountTarget
                        appSetting:(AppSetting*)pAppSetting
{
    self.category        = pCategory;
    self.title           = psTitle;
    self.dateCreate      = [NSDate date];
    self.dateLastRead    = self.dateCreate;
    self.countTarget     = pCountTarget;
    self.countNow        = [NSNumber numberWithInt:0];
    self.countTotal	     = [NSNumber numberWithInt:0];
    self.percentComplete = [NSNumber numberWithFloat:0.0f];
    unsigned int nIdKey = [pAppSetting nextId];
    self.idKey           = [NSNumber numberWithUnsignedInt:nIdKey];
}

//---------------------------------------------------------------------------
- (void)defaultSettingWithCategory:(ECategory)eCategory appSetting:(AppSetting*)pAppSetting
{
    
    NSString *psTitle;
    int      nCountTarget = 1000;
    switch(eCategory) {
        case eCategory_Verse:
            psTitle = NSLocalizedString(@"Nomo Amitabha",  @"default tilte for the first verse");
            break;
        case eCategory_Book:
            psTitle = NSLocalizedString(@"Amitabha Sutra", @"default tilte for the first book");
            nCountTarget = 108;
            break;
        case eCategory_Other:
            psTitle = NSLocalizedString(@"The Great Dharani", @"default tilte for the first other");
            break;
        default:
            psTitle = NSLocalizedString(@"New Title", @"default title of a new book");
            nCountTarget = 108;
            eCategory = eCategory_Verse; /* new title's category */
            break;
    }
    [self defaultSettingWithCategory:[NSNumber numberWithInt:eCategory]
                               title:psTitle
                         countTarget:[NSNumber numberWithInt:nCountTarget]
                          appSetting:pAppSetting];
}

//===========================================================================
@end

