// 
//  AppSetting.m
//  
//
//  Created by LinCheng Wang on 6/8/10.
//  Copyright 2010 AuroraWand.com. All rights reserved.
//

#import "AppSetting.h"

#import "Book.h"

@interface AppSetting (Private)
- (NSString *)dataFilePath;
@end

@implementation AppSetting 

@synthesize bPlaySound;
@synthesize sortingKey;
@synthesize bCountingOrder;
@synthesize countSession;
@synthesize idCounter;

@synthesize readBookIdKey;

//-----------------------------------------------------------------------------
- (id)initByReadFromFile
{
/* init super first */
    if((self = [super init]) == nil) {
        return self;
    }
    
/* read or initialize */
    NSString *psFilePath = [self dataFilePath];

    if([[NSFileManager defaultManager] fileExistsAtPath:psFilePath]) {
        NSArray *pArray = [[NSArray alloc] initWithContentsOfFile:psFilePath];
        self.bPlaySound       = (NSNumber*)[pArray objectAtIndex:0];
        self.sortingKey       = (NSNumber*)[pArray objectAtIndex:1];
        self.bCountingOrder   = (NSNumber*)[pArray objectAtIndex:2];
        self.countSession     = (NSNumber*)[pArray objectAtIndex:3];
        self.idCounter	      = (NSNumber*)[pArray objectAtIndex:4];
        self.readBookIdKey    = (NSNumber*)[pArray objectAtIndex:5];
        [pArray release];
    } else {
#define THE_FIRST_IDKEY        1
#define THE_FIRST_NEW_IDKEY    1
        /* If the expected store doesn't exist, initialize it. */
        self.bPlaySound       = [NSNumber numberWithInt:YES];
        self.sortingKey       = [NSNumber numberWithInt:eSortingKey_DateCreate];
        self.bCountingOrder   = [NSNumber numberWithInt:kCountingOrderUp];
        self.countSession     = [NSNumber numberWithInt:10];    /* TODO: 108 */
        self.idCounter	      = [NSNumber numberWithUnsignedInt:THE_FIRST_NEW_IDKEY];
        self.readBookIdKey    = [NSNumber numberWithInt:THE_FIRST_IDKEY];
        [self writeToFile];
    }
/* return self */
    return self;
}

//-----------------------------------------------------------------------------
- (void)writeToFile
{
    NSString *psFilePath = [self dataFilePath];

    NSArray *pArray = [[NSArray alloc] initWithObjects:bPlaySound,
                                                       sortingKey,
                                                       bCountingOrder,
                                                       countSession,
                                                       idCounter,
                                                       readBookIdKey, nil];
    [pArray writeToFile:psFilePath atomically:YES];
    [pArray release];
}

//---------------------------------------------------------------------------
+ (NSString*)sortingKeyInLocalizedString:(ESortingKey)eSortingKey
{
    NSString *psString;
    switch(eSortingKey){
        case eSortingKey_Title:
            psString = NSLocalizedString(@"Title",    @"sorting key - title");
            break;
        case eSortingKey_DateCreate:
            psString = NSLocalizedString(@"Date",     @"sorting key - dateCreated");
            break;
        case eSortingKey_PercentComplete:
            psString = NSLocalizedString(@"Complete", @"sorting key - percentComplete");
            break;
    }
    return psString;
}

//-----------------------------------------------------------------------------
- (NSString*)sortingKeyInString
{
/* since we have many pre-set item list in each category
 * Jill suggests the last-read date, instead of created date as sorting key.
 */
    NSArray *pSortingKeyArray = [NSArray arrayWithObjects:
        //@"dateCreate", @"percentComplete", @"dateLastRead", @"title", nil];
        //@"title", @"dateCreate", @"percentComplete",  nil];
        @"title", @"dateLastRead", @"percentComplete",  nil];                         
    return [pSortingKeyArray objectAtIndex:[self.sortingKey intValue]];
}

//-----------------------------------------------------------------------------
- (BOOL)sortingKeyIsAscending
{
    int nSortingKeyInInt = [self.sortingKey intValue];
    return (nSortingKeyInInt == eSortingKey_Title) ? YES : NO;
}

//-----------------------------------------------------------------------------
- (NSString *)dataFilePath
{
    NSString *psDocDir = [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) objectAtIndex:0];
    NSString *psFilePath = [psDocDir stringByAppendingPathComponent: @"AppSetting.plist"];
    return psFilePath;
}

//-----------------------------------------------------------------------------
- (unsigned int)nextId
{
    unsigned int nNextId = [idCounter unsignedIntValue];
    self.idCounter = [NSNumber numberWithUnsignedInt:nNextId + 1];
    return nNextId;
}

//-----------------------------------------------------------------------------
- (void)setReadBook:(Book*)pBook
{
    self.readBookIdKey = pBook.idKey; /* a copy */
}

//-----------------------------------------------------------------------------
- (BOOL)isReadBook:(Book*)pBook
{
    return [readBookIdKey isEqualToNumber:pBook.idKey];
}

//=============================================================================
@end
