/*!
 * \file UtilMsg.m
 *     A utility to log messages by giving debug level
 */
/***************************************************************************/
/* Copyright (c) 2009 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/10/09                                    */
/***************************************************************************/

/****************************************************************************
 * COMPILATION OPTIONS
 ***************************************************************************/

/****************************************************************************
 * HEADER FILES
 ***************************************************************************/
#import "UtilMsg.h"

/****************************************************************************
 * MACROS
 ***************************************************************************/

/****************************************************************************
 * INLINE FUNCTIONS
 ***************************************************************************/

/****************************************************************************
 * TYPEDEF and DATA STRUCTURE
 ***************************************************************************/

/****************************************************************************
 * EXTERNAL VARIABLES
 ***************************************************************************/

/****************************************************************************
 * GLOBAL VARIABLES
 ***************************************************************************/

/****************************************************************************
 * LOCAL VARIABLES
 ***************************************************************************/

/****************************************************************************
 * EXTERNAL FUNCTIONS
 ***************************************************************************/

/****************************************************************************
 * PRIVATE FUNCTIONS
 ***************************************************************************/

/****************************************************************************
 * UTILITY METHODS
 ***************************************************************************/
void _UtilMsg(const char *pcFile, const int nLineNum, const char *pcFunc, NSString *pFormat, ...)
{
    va_list ap;

    va_start(ap, pFormat);
    if(![pFormat hasSuffix: @"\n"]) {
        pFormat = [pFormat stringByAppendingString: @"\n"];
    }
    NSString *pBody = [[NSString alloc] initWithFormat: pFormat arguments: ap];
    va_end(ap);

    NSString *pFileName =[[NSString stringWithUTF8String:pcFile] lastPathComponent];
    const char *pcThreadName = [[[NSThread currentThread] name] UTF8String];
    if(pcThreadName) {
        fprintf(stderr, "%s/%s (%s:%d) %s", pcThreadName,
                pcFunc, [pFileName UTF8String], nLineNum, [pBody UTF8String]);
    } else {
        fprintf(stderr, "%p/%s (%s:%d) %s", [NSThread currentThread],
                pcFunc, [pFileName UTF8String], nLineNum, [pBody UTF8String]);
    }
    [pBody release];
}

