/*!
 * \file BookAddViewCtrl.h
 *      Implement Add (Book) View Controller for BuddhaCounter project
 *
 * The table view controller responsible managing addition of a new book to the application.
 * When editing ends, the controller sends a message to its delegate
 * (in this case, the root view controller) to tell it that it finished editing and
 * whether the user saved their changes.
 * It's up to the delegate to actually commit the changes.
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/27/10                                    */
/***************************************************************************/

//=============================================================================
// COMPILATION OPTIONS
//=============================================================================
//#define DEBUG_LEVEL     /* to turn on message utility by UtilMsg.h */

//=============================================================================
// HEADER FILES
//=============================================================================
#import "BookDetailViewCtrl.h"

//=============================================================================
// MACROS & INLINE FUNCTIONS
//=============================================================================

//=============================================================================
// TYPEDEFS & DATA STRUCTURES
//=============================================================================

//=============================================================================
// CLASS INTERFACE
//=============================================================================
@protocol BookAddViewCtrlDelegate;

@interface BookAddViewCtrl : BookDetailViewCtrl {
	id <BookAddViewCtrlDelegate> bookAddViewCtrlDelegate;
}

@property (nonatomic, assign) id <BookAddViewCtrlDelegate> bookAddViewCtrlDelegate;

//=============================================================================
// METHODS
//=============================================================================
- (IBAction)onCancel:(id)sender;
- (IBAction)onSave:(id)sender;

//=============================================================================
@end    /* BookAddViewCtrl */

//=============================================================================
// PROTOCOL METHODS
//=============================================================================
@protocol BookAddViewCtrlDelegate
- (void)bookAddViewCtrl:(BookAddViewCtrl *)pViewCtrl didFinishWithSave:(BOOL)bIsSave;

//=============================================================================
@end    /* BookAddViewCtrlDelegate */

