/*!
 * \file BookAddViewCtrl.m
 *      Implement Add (Book) View Controller for BuddhaCounter project
 *
 * The table view controller responsible managing addition of a new book to the application.
 * When editing ends, the controller sends a message to its delegate
 * (in this case, the root view controller) to tell it that it finished editing and
 * whether the user saved their changes.
 * It's up to the delegate to actually commit the changes.
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/27/10                                    */
/***************************************************************************/

//=============================================================================
// COMPILATION OPTIONS
//=============================================================================
//#define DEBUG_LEVEL     /* to turn on message utility by UtilMsg.h */

//=============================================================================
// HEADER FILES
//=============================================================================
#import "BookAddViewCtrl.h"
#import "AppModel.h"

//=============================================================================
// MACROS & INLINE FUNCTIONS
//=============================================================================

//=============================================================================
// TYPEDEFS & DATA STRUCTURES
//=============================================================================

//=============================================================================
// CLASS IMPLEMENTATION
//=============================================================================
@implementation BookAddViewCtrl

@synthesize bookAddViewCtrlDelegate;

//=============================================================================
// METHODS
//=============================================================================
#pragma mark -
#pragma mark View lifecycle

//-----------------------------------------------------------------------------
- (void)viewDidLoad {
	
	[super viewDidLoad];
/* Override the BookDetailViewCtrl viewDidLoad with different navigation bar items and title. */
    self.title = NSLocalizedString(@"New Book", @"the view title of adding a new book view");
    self.navigationItem.leftBarButtonItem = [[[UIBarButtonItem alloc]
                       initWithBarButtonSystemItem:UIBarButtonSystemItemCancel
                                            target:self
                                            action:@selector(onCancel:)]
                                            autorelease];
    self.navigationItem.rightBarButtonItem = [[[UIBarButtonItem alloc]
                       initWithBarButtonSystemItem:UIBarButtonSystemItemSave
                                            target:self
                                            action:@selector(onSave:)]
                                            autorelease];
	
	// Set up the undo manager and set editing state to YES.
	//[self setUpUndoManager];
	self.editing = YES; /* inherited property */
    self.eEditMode = eEditMode_Add;

#if 0
/* non-optional properties */
    self.book.dateLastRead = [NSDate date];
    self.book.dateCreate   = self.book.dateLastRead;
    self.book.title        = NSLocalizedString(@"New Title", @"default title of a new book");
#endif
}

//-----------------------------------------------------------------------------
- (void)viewDidUnload {
	[super viewDidUnload];
	// Release any properties that are loaded in viewDidLoad or can be recreated lazily.
	//[self cleanUpUndoManager];	
}

//=============================================================================
// ACTION METHODS
//=============================================================================
#pragma mark -
#pragma mark Save and cancel operations

//-----------------------------------------------------------------------------
- (IBAction)onCancel:(id)sender {
    [self onDone];  /* of BookDetail */
	[bookAddViewCtrlDelegate bookAddViewCtrl:self didFinishWithSave:NO];
}

//-----------------------------------------------------------------------------
- (IBAction)onSave:(id)sender {
    [self onDone];  /* of BookDetail */
	[bookAddViewCtrlDelegate bookAddViewCtrl:self didFinishWithSave:YES];
}

//=============================================================================
@end    /* BookAddViewCtrl */
