/*!
 * \file  BookListViewCtrl.h
 *       Implement BookList View Controller for BuddhaCounter project
 *
 * Abstract: The table view controller responsible for displaying the
 *           list of books, supporting additional functionality:
 *      - Addition of new new books;
 *      - Deletion of existing books using UITableView's
 *        tableView:commitEditingStyle:forRowAtIndexPath: method.
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/25/10                                    */
/***************************************************************************/

//=============================================================================
// COMPILATION OPTIONS
//=============================================================================
//#define DEBUG_LEVEL     /* to turn on message utility by UtilMsg.h */

//=============================================================================
// HEADER FILES
//=============================================================================
#import <UIKit/UIKit.h>
#import <CoreData/CoreData.h>

#import "BookAddViewCtrl.h"

//=============================================================================
// MACROS & INLINE FUNCTIONS
//=============================================================================

//=============================================================================
// TYPEDEFS & DATA STRUCTURES
//=============================================================================

//=============================================================================
// CLASS INTERFACE
//=============================================================================
@protocol BookListViewCtrlDelegate;
@class AppSetting;

@interface BookListViewCtrl : UIViewController
        <UITableViewDelegate, UITableViewDataSource,
        NSFetchedResultsControllerDelegate,
        BookAddViewCtrlDelegate, BookDetailViewCtrlDelegate> 
{
    id <BookListViewCtrlDelegate> delegate;

/* User Interface */ 
    UIImageView                 *xpBgView;
    UITableView                 *xpTableView;
    UISegmentedControl          *xpSortingKey;
    UILabel						*xpSortingLabel;
    
/* AppSetting */
    AppSetting                  *mpAppSetting;                  //!< app setting

@private
/* data model */
    NSFetchedResultsController  *fetchedResultsController;      //!< fetch result
    NSManagedObjectContext      *managedObjectContext;          //!< context, created and assigned by AppDelegate
    NSManagedObjectContext      *addingManagedObjectContext;    //!< context to add a new entity
#ifdef __IPHONE_3_1
    NSUInteger                  sectionInsertCount;
#endif  /* __IPHONE_3_1 */
    bool                        mbIsUpdated;
}

@property (nonatomic, assign) id <BookListViewCtrlDelegate> delegate;
/* User Interface */ 
@property (nonatomic, retain) IBOutlet UIImageView          *xpBgView;
@property (nonatomic, retain) IBOutlet UITableView          *xpTableView;
@property (nonatomic, retain) IBOutlet UISegmentedControl   *xpSortingKey;
@property (nonatomic, retain) IBOutlet UILabel				*xpSortingLabel;

/* data model */
@property (nonatomic, retain) NSFetchedResultsController    *fetchedResultsController;
@property (nonatomic, retain) NSManagedObjectContext        *managedObjectContext;
@property (nonatomic, retain) NSManagedObjectContext        *addingManagedObjectContext;

/* AppSetting */
@property (nonatomic, retain)             AppSetting        *mpAppSetting;


//=============================================================================
// METHODS
//=============================================================================
- (IBAction)onDone;

- (IBAction)onAddBook;
- (IBAction)onSortingKey;

//=============================================================================
@end    /* BookListViewCtrl */

//=============================================================================
// PROTOCOL METHODS
//=============================================================================
@protocol BookListViewCtrlDelegate
- (void)bookListViewCtrlDidFinish:(BookListViewCtrl *)controller isUpdated:(bool)bIsUpdated;

//=============================================================================
@end    /* BookListViewCtrlDelegate */
