/*!
 * \file BuddhaCounterAppDelegate.m
 *      Implement App Delegate for BuddhaCounter project
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/27/10                                    */
/***************************************************************************/

//=============================================================================
// COMPILATION OPTIONS
//=============================================================================
//#define DEBUG_LEVEL     /* to turn on message utility by UtilMsg.h */

//=============================================================================
// HEADER FILES
//=============================================================================
#import "BuddhaCounterAppDelegate.h"
#import "MainViewCtrl.h"

#import "AppModel.h"
#import "AppSetting.h"

//=============================================================================
// MACROS & INLINE FUNCTIONS
//=============================================================================
/* from 1.0 to 0.5 (not 0.8) updated on 6/24/10 */
#define SPLASH_DURATION 0.9		/* in sec */

//=============================================================================
// TYPEDEFS & DATA STRUCTURES
//=============================================================================

//==============================================================================
// PRIVATE METHOD
//==============================================================================
@interface BuddhaCounterAppDelegate (Private)
- (void)showSplash;
- (void)removeSplash;
//- (void)getAppSetting;
@end

//=============================================================================
// CLASS IMPLEMENTATION
//=============================================================================
@implementation BuddhaCounterAppDelegate

@synthesize window;
@synthesize mpMainViewCtrl;
@synthesize mpAppSetting;


//==============================================================================
// METHOD
//==============================================================================
//------------------------------------------------------------------------------
/*! Tells the delegate when the application has launched
 * due to a remote notification or the opening of a URL resource.
 */
- (BOOL)application:(UIApplication *)application
                didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{    
/* Turn off the idle timer, since this app doesn't rely on constant touch input
 * revision 1.1 10/07/16: enable idle time
 */
    //application.idleTimerDisabled = YES;

/* splash */
    [self showSplash];
    [window makeKeyAndVisible];

#if 0
    NSString   *language = [[NSLocale currentLocale] objectForKey: NSLocaleLanguageCode];
    NSString   *countryCode = [[NSLocale currentLocale] objectForKey: NSLocaleCountryCode];
    NSLog(@"langurage=%@", language);
    NSLog(@"countryCode = %@", countryCode);
/* local */
    NSLocale *locale = [NSLocale currentLocale];
    NSString *localIdInString = [locale displayNameForKey:NSLocaleIdentifier
                                                       value:[locale localeIdentifier]];
    NSLog(@"localIdentifier=%@", localIdInString);
    NSLog(@"languageCode=%@", [[NSLocale preferredLanguages] objectAtIndex:0]);
    NSLog(@"languageCode=%@", [locale displayNameForKey:NSLocaleLanguageCode
                                                  value:[locale localeIdentifier]]);
#endif
    
/* allocate and run MainViewCtrl */
	MainViewCtrl *pController = [[MainViewCtrl alloc] initWithNibName:@"MainView" bundle:nil];
	self.mpMainViewCtrl = pController;
	[pController release];
	
/* read AppSetting */
    AppSetting *pAppSetting = [[AppSetting alloc] initByReadFromFile];
    self.mpAppSetting = pAppSetting;
    [pAppSetting release];

/* assign managedObjectContext before viewDidLoad */
    mpMainViewCtrl.managedObjectContext = self.managedObjectContext;
    //mpMainViewCtrl.mpAppSetting         = self.mpAppSetting;
    mpMainViewCtrl.mpAppSetting         = self.mpAppSetting;
    mpMainViewCtrl.view.frame           = [UIScreen mainScreen].applicationFrame;

/* show windows */
	[window addSubview:[mpMainViewCtrl view]];
    [window sendSubviewToBack:mpMainViewCtrl.view];

	return YES;
}

//------------------------------------------------------------------------------
/*! applicationWillTerminate: saves changes in the application's managed object context
 * before the application terminates.
 */
- (void)applicationWillTerminate:(UIApplication *)application {
	
#if 0   /* not used int this project */
/* TODO: add badgeNumber here */
    NSInteger nBadgeNumber = 88;
    [[UIApplication sharedApplication] setApplicationIconBadgeNumber:nBadgeNumber];
#endif

/* save AppSetting */
    [mpAppSetting writeToFile];

/* save database */
    NSError *error = nil;
    if((managedObjectContext != nil) && [managedObjectContext hasChanges]) {
        if(![managedObjectContext save:&error]) {
			/* Replace this implementation with code to handle the error appropriately.
             *
             * abort() causes the application to generate a crash log and terminate.
             * You should not use this function in a shipping application,
             * although it may be useful during development.
             * If it is not possible to recover from the error,
             * display an alert panel that instructs the user to quit the application
             * by pressing the Home button.
			 */
#ifdef DEVELOPMENT_ONLY
			NSLog(@"TheEnd - Unresolved error %@, %@", error, [error userInfo]);
            abort();
#endif
        } 
    }
}

#pragma mark -
#pragma mark Saving

//------------------------------------------------------------------------------
/**
 Performs the save action for the application, which is to send the save:
 message to the application's managed object context.
 */
- (IBAction)onSaveAction:(id)sender
{
    NSError *error;
    if(![[self managedObjectContext] save:&error]) {
        // Handle error
    }
}

#pragma mark -
#pragma mark Core Data stack

//------------------------------------------------------------------------------
/**
 Returns the managed object context for the application.
 If the context doesn't already exist, it is created and bound to the persistent store coordinator for the application.
 */
- (NSManagedObjectContext *)managedObjectContext {
	
    if(managedObjectContext != nil) {
        return managedObjectContext;
    }
	
    NSPersistentStoreCoordinator *coordinator = [self persistentStoreCoordinator];
    if(coordinator != nil) {
        managedObjectContext = [[NSManagedObjectContext alloc] init];
        [managedObjectContext setPersistentStoreCoordinator: coordinator];
    }
    return managedObjectContext;
}


//------------------------------------------------------------------------------
/**
 Returns the managed object model for the application.
 If the model doesn't already exist, it is created by merging all of the models found in the application bundle.
 */
- (NSManagedObjectModel *)managedObjectModel {
	
    if(managedObjectModel != nil) {
        return managedObjectModel;
    }
    managedObjectModel = [[NSManagedObjectModel mergedModelFromBundles:nil] retain];    
    return managedObjectModel;
}


//------------------------------------------------------------------------------
/**
 Returns the persistent store coordinator for the application.
 If the coordinator doesn't already exist, it is created and the application's store added to it.
 */
- (NSPersistentStoreCoordinator *)persistentStoreCoordinator
{
/* return, if it has been created */
    if(persistentStoreCoordinator != nil) {
        return persistentStoreCoordinator;
    }

/* make sure there is a copy sqlite database in Documents (in sandbox), named as storeUrl */
    NSString *storePath = [[self applicationDocumentsDirectory]
                             stringByAppendingPathComponent: @"BuddhaCounter.sqlite"];
    //NSLog(@"%@", storePath);

#if 0
/* Set up the store.
 * For the sake of illustration, provide a pre-populated default store.
 */
    NSFileManager *fileManager = [NSFileManager defaultManager];
    // If the expected store doesn't exist, copy the default store.
    if(![fileManager fileExistsAtPath:storePath]) {
        NSString *defaultStorePath = [[NSBundle mainBundle]
                                        pathForResource:@"BuddhaCounter"
                                                 ofType:@"sqlite"];
        if(defaultStorePath) {
            [fileManager copyItemAtPath:defaultStorePath toPath:storePath error:NULL];
        }
    }
#endif
    
    NSURL *storeUrl = [NSURL fileURLWithPath:storePath];
    
/* Allow inferred migration from the original version of the application. */
    NSDictionary *options = [NSDictionary dictionaryWithObjectsAndKeys:
                             [NSNumber numberWithBool:YES], NSMigratePersistentStoresAutomaticallyOption,
                             [NSNumber numberWithBool:YES], NSInferMappingModelAutomaticallyOption, nil];
    
/* create a persistentStoreCoordinator */
    persistentStoreCoordinator = [[NSPersistentStoreCoordinator alloc]
                                    initWithManagedObjectModel:[self managedObjectModel]];
    NSError *error;
    if(![persistentStoreCoordinator addPersistentStoreWithType:NSSQLiteStoreType
                                                 configuration:nil
                                                           URL:storeUrl
                                                       options:options error:&error]) {
        // Update to handle the error appropriately.
        /*
		 * Replace this implementation with code to handle the error appropriately.
		 * 
		 * abort() causes the application to generate a crash log and terminate.
         * You should not use this function in a shipping application,
         * although it may be useful during development.
         * If it is not possible to recover from the error,
         * display an alert panel that instructs the user to quit the application
         * by pressing the Home button.
         *
         * Typical reasons for an error here include:
		 * The persistent store is not accessible
		 * The schema for the persistent store is incompatible with current managed object model
		 * Check the error message to determine what the actual problem was.
		 */
#ifdef DEVELOPMENT_ONLY
        NSLog(@"Unresolved error %@, %@", error, [error userInfo]);
        abort();
#endif
    }
    
    return persistentStoreCoordinator;    
}


#pragma mark -
#pragma mark Application's Documents directory

//------------------------------------------------------------------------------
/**
 Returns the path to the application's Documents directory.
 */
- (NSString *)applicationDocumentsDirectory {
	//return [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) lastObject];
    return [NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) objectAtIndex:0];
}


#pragma mark -
#pragma mark Memory management

//------------------------------------------------------------------------------
- (void)dealloc {
	
    [managedObjectContext release];
    [managedObjectModel release];
    [persistentStoreCoordinator release];
    
    [mpAppSetting release];
    
    [mpMainViewCtrl release];
    [window release];
    [super dealloc];
}

//==============================================================================
// PRIVATE METHOD
//==============================================================================
//------------------------------------------------------------------------------
- (void)showSplash
{
    mpSplashView = [[UIImageView alloc] initWithFrame:CGRectMake(0, 0, 320, 480)];
    mpSplashView.image = [UIImage imageNamed:@"Default.png"];
    [window addSubview:mpSplashView];
    [window bringSubviewToFront:mpSplashView];
#if 0
    [self performSelector:@selector(removeSplash) withObject:nil afterDelay:0.8];
#else
    [UIView beginAnimations:nil context:nil];
    [UIView setAnimationDelegate:self];
    [UIView setAnimationDuration:SPLASH_DURATION];
    [UIView setAnimationDidStopSelector:@selector(removeSplash)];
    mpSplashView.alpha = 0.1;
    [UIView commitAnimations];
#endif
}

//------------------------------------------------------------------------------
- (void)removeSplash
{
    [mpSplashView removeFromSuperview];
    [mpSplashView release];
}

#if 0
//------------------------------------------------------------------------------
- (void)getAppSetting
{
/* Fetch existing events.
 * Create a fetch request, add a sort descriptor, then execute the fetch.
 *
 * Trick: use self.managedObjectContext to allocate and initialize it.
 */
    NSFetchRequest *request = [[NSFetchRequest alloc] init];
    NSEntityDescription *entity = [NSEntityDescription entityForName:@"AppSetting"
                                              inManagedObjectContext:self.managedObjectContext];
    [request setEntity:entity];

/* Order the events by creation date, most recent first. */
    NSSortDescriptor *sortDescriptor = [[NSSortDescriptor alloc]
                        initWithKey:@"bCountingOrder" ascending:NO];
    NSArray *sortDescriptors = [[NSArray alloc] initWithObjects:sortDescriptor, nil];
    [request setSortDescriptors:sortDescriptors];
    [sortDescriptor release];
    [sortDescriptors release];

    // Execute the fetch -- create a mutable copy of the result.
    NSError *error = nil;
    NSMutableArray *mutableFetchResults = [[managedObjectContext executeFetchRequest:request
                                                                               error:&error] mutableCopy];
    if(mutableFetchResults == nil) {    /* insert one */
        /* Handle the error. */
    }
    
    if([mutableFetchResults count] == 0) {
        /* Create a new instance of the Setting entity.  */
        AppSetting *pAppSetting = (AppSetting *)[NSEntityDescription
                                    insertNewObjectForEntityForName:@"AppSetting"
                                             inManagedObjectContext:managedObjectContext];
        [pAppSetting defaultSetting];

        /* Create 3 new instances of the Book entity */
        Book *pBookVerse = (Book *)[NSEntityDescription
                insertNewObjectForEntityForName:@"Book" inManagedObjectContext:managedObjectContext];
        [pBookVerse defaultSettingWithCategory:eCategory_Verse];
        Book *pBookBook = (Book *)[NSEntityDescription
                insertNewObjectForEntityForName:@"Book" inManagedObjectContext:managedObjectContext];
        [pBookBook  defaultSettingWithCategory:eCategory_Book];
        Book *pBookOther = (Book *)[NSEntityDescription
                insertNewObjectForEntityForName:@"Book" inManagedObjectContext:managedObjectContext];
        [pBookOther defaultSettingWithCategory:eCategory_Other];

        /* Configure the new setting with information from the location. */
        pAppSetting.selectedBook = pBookVerse;

        // Commit the change.
        NSError *error;
        if(![managedObjectContext save:&error]) {
            // Handle the error.
        }
        /* keep it in memory */
        self.mpAppSetting = pAppSetting;
    } else {
        /* Set self's setting array to the mutable array, then clean up. */
        self.mpAppSetting = [mutableFetchResults objectAtIndex:0];
    }
    [mutableFetchResults release];
    [request release];    
}
#endif

//==============================================================================
@end
