/*!
 * \file EditingViewCtrl.h
 *      The table view controller responsible for editing a field of data, text or date.
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/26/10                                    */
/***************************************************************************/

//=============================================================================
// COMPILATION OPTIONS
//=============================================================================
//#define DEBUG_LEVEL     /* to turn on message utility by UtilMsg.h */

//=============================================================================
// HEADER FILES
//=============================================================================
#include <CoreData/CoreData.h>

//=============================================================================
// MACROS & INLINE FUNCTIONS
//=============================================================================

//=============================================================================
// TYPEDEFS & DATA STRUCTURES
//=============================================================================
typedef enum {
    eDataType_Text,
    eDataType_Number,
    eDataType_Date,
} EDataType;

//=============================================================================
// CLASS INTERFACE
//=============================================================================
@protocol EditingViewCtrlDelegate;

@interface EditingViewCtrl : UIViewController {

    id <EditingViewCtrlDelegate> delegate;
	
/* user interface */
	UITextField         *xpTextField;
	UITextField         *xpNumberField;
	UIDatePicker        *xpDatePicker;

/* data */
    EDataType           meDataType;
    NSInteger           mnNumberMax;
    NSInteger           mnNumberMin;

/* input */
    NSManagedObject     *editedObject;
    NSInteger            editedFieldId;
    NSString            *editedFieldKey;
    NSString            *editedFieldName;
}

@property (nonatomic, assign)          id <EditingViewCtrlDelegate> delegate;
/* user interface */
@property (nonatomic, retain) IBOutlet UITextField     *xpTextField;
@property (nonatomic, retain) IBOutlet UITextField     *xpNumberField;
@property (nonatomic, retain) IBOutlet UIDatePicker    *xpDatePicker;

/* data */
@property (nonatomic, assign)          EDataType        meDataType;
@property (nonatomic, assign)          NSInteger        mnNumberMax;
@property (nonatomic, assign)          NSInteger        mnNumberMin;

/* input */
@property (nonatomic, retain)          NSManagedObject *editedObject;
@property (nonatomic, assign)          NSInteger        editedFieldId;
@property (nonatomic, retain)          NSString        *editedFieldKey;
@property (nonatomic, retain)          NSString        *editedFieldName;

//=============================================================================
// METHODS
//=============================================================================
- (IBAction)onCancel;
- (IBAction)onSave;

//=============================================================================
@end    /* EditingViewCtrl */

//=============================================================================
// PROTOCOL METHODS
//=============================================================================
@protocol EditingViewCtrlDelegate
- (void)editingViewCtrlDidSave:(EditingViewCtrl *)pCtrl;

//=============================================================================
@end    /* EditingViewCtrlDelegate */
