/*!
 * \file HelpViewCtrl.m
 *      Implement Help View Controller for BuddhaCounter project
 *
 * Supported by xib of Interface Builder (IB)
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/31/10                                    */
/***************************************************************************/

//=============================================================================
// HEADER FILES
//=============================================================================
#import "HelpViewCtrl.h"

//=============================================================================
// CLASS IMPLEMENTATION
//=============================================================================
@implementation HelpViewCtrl

@synthesize xpScrollView, xpImageView, xpPageControl;

//=============================================================================
// METHODS
//=============================================================================
//-----------------------------------------------------------------------------
- (void)viewDidLoad {
    [super viewDidLoad];
    self.title = NSLocalizedString(@"Help", @"the view title of Help view");
    self.view.backgroundColor = [UIColor viewFlipsideBackgroundColor];      

/* ScrollView (hacked for IB's incapability) */
    xpScrollView.contentSize = [xpImageView.image size];
    /* TODO: verify */
    xpPageControl.numberOfPages = xpImageView.image.size.width / self.view.bounds.size.width;
    //NSLog(@"%d", xpPageControl.numberOfPages);
/* page control, if necessary */
    mbIsPageControlUsed = NO;
}

//-----------------------------------------------------------------------------
- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}


//-----------------------------------------------------------------------------
- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
    self.xpScrollView  = nil;
    self.xpImageView   = nil;
    self.xpPageControl = nil;
}

/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
	// Return YES for supported orientations
	return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

//-----------------------------------------------------------------------------
- (void)dealloc {
    [xpScrollView  release];
    [xpImageView   release];
    [xpPageControl release];
    [super dealloc];
}

//=============================================================================
// ACTION METHODS
//=============================================================================

//-----------------------------------------------------------------------------
- (IBAction)onPageControl
{
    const int page = xpPageControl.currentPage;

/* update ScrollView's view port */
    CGRect frame = xpScrollView.frame;
    frame.origin.x = frame.size.width * page;
    frame.origin.y = 0;
    [xpScrollView scrollRectToVisible:frame animated:YES];
    mbIsPageControlUsed = YES;
}

//=============================================================================
// PROTOCOL METHODS
//=============================================================================
#pragma mark UIScrollViewDelegate methods

//-----------------------------------------------------------------------------
- (void)scrollViewDidScroll:(UIScrollView *)sender
{
/* do nothing, if it is driven by PageControl */
    if(mbIsPageControlUsed) {
        return;
    }

/* update PageControl's currentPage */
    CGFloat pageWidth = xpScrollView.frame.size.width;
    int page = floor((xpScrollView.contentOffset.x - pageWidth / 2) / pageWidth) + 1;
    xpPageControl.currentPage = page;
}

//-----------------------------------------------------------------------------
- (void)scrollViewDidEndDecelerating:(UIScrollView *)scrollView
{
    mbIsPageControlUsed = NO;
}

//=============================================================================
@end    /* HelpViewCtrl */
