/*!
 * \file InfoViewCtrl.m
 *      Implement Info View Controller for BuddhaCounter project
 *
 * Supported by xib of Interface Builder (IB)
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/31/10                                    */
/***************************************************************************/

//=============================================================================
// HEADER FILES
//=============================================================================
#import "InfoViewCtrl.h"

//=============================================================================
// CLASS IMPLEMENTATION
//=============================================================================
@implementation InfoViewCtrl

@synthesize xpBgView;
@synthesize xpTextView;
@synthesize xpScrollView, xpImageViewScroll, xpPageControl;

//=============================================================================
// METHODS
//=============================================================================
//-----------------------------------------------------------------------------
- (void)viewDidLoad {
    [super viewDidLoad];
    self.title = NSLocalizedString(@"Information", @"the view title of information view");
    //self.view.backgroundColor = [UIColor viewFlipsideBackgroundColor];      

/* ScrollView (hacked for IB's incapability) */
    xpScrollView.contentSize = [xpImageViewScroll.image size];
/* page control, if necessary */
    mbIsPageControlUsed = NO;
}

//-----------------------------------------------------------------------------
- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}


//-----------------------------------------------------------------------------
- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
    self.xpBgView          = nil;
    self.xpTextView        = nil;
    self.xpScrollView      = nil;
    self.xpImageViewScroll = nil;
    self.xpPageControl     = nil;
}

/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
	// Return YES for supported orientations
	return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

//-----------------------------------------------------------------------------
- (void)dealloc {
    [xpBgView          release];
    [xpTextView        release];
    [xpScrollView      release];
    [xpImageViewScroll release];
    [xpPageControl     release];

    [super dealloc];
}

//=============================================================================
// ACTION METHODS
//=============================================================================
//-----------------------------------------------------------------------------
- (IBAction)onPageControl
{
    const int page = xpPageControl.currentPage;

/* update ScrollView's view port */
    CGRect frame = xpScrollView.frame;
    frame.origin.x = frame.size.width * page;
    frame.origin.y = 0;
    [xpScrollView scrollRectToVisible:frame animated:YES];
    mbIsPageControlUsed = YES;
}

//=============================================================================
// PROTOCOL METHODS
//=============================================================================
#pragma mark UIScrollViewDelegate methods

//-----------------------------------------------------------------------------
- (void)scrollViewDidScroll:(UIScrollView *)sender
{
/* do nothing, if it is driven by PageControl */
    if(mbIsPageControlUsed) {
        return;
    }

/* update PageControl's currentPage */
    CGFloat pageWidth = xpScrollView.frame.size.width;
    int page = floor((xpScrollView.contentOffset.x - pageWidth / 2) / pageWidth) + 1;
    xpPageControl.currentPage = page;
}

//-----------------------------------------------------------------------------
- (void)scrollViewDidEndDecelerating:(UIScrollView *)scrollView
{
    mbIsPageControlUsed = NO;
}

//=============================================================================
@end    /* InfoViewCtrl */
