/*!
 * \file  MainViewCtrl.h
 *       Implement MainView controller for BuddhaCounter project
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/25/10                                    */
/***************************************************************************/

//=============================================================================
// COMPILATION OPTIONS
//=============================================================================
//#define DEBUG_LEVEL     /* to turn on message utility by UtilMsg.h */

//=============================================================================
// HEADER FILES
//=============================================================================
#import <CoreData/CoreData.h>
#import "BookListViewCtrl.h"
#import "OptionViewCtrl.h"

//=============================================================================
// MACROS & INLINE FUNCTIONS
//=============================================================================
#define kCounterNumComp     6

//=============================================================================
// CLASS INTERFACE
//=============================================================================
@class AVAudioPlayer;
@class AppSetting;

@interface MainViewCtrl : UIViewController
        <BookListViewCtrlDelegate, OptionViewCtrlDelegate,
         NSFetchedResultsControllerDelegate,
         UIPickerViewDelegate, UIPickerViewDataSource>
{
/* View */
    UIPickerView            *xpPickerBook;          //!< to select a book
    UIPickerView            *xpPickerCounter;       //!< as a counter
    UIButton                *xpBtnCountUp;          //!< counting up
    UIButton                *xpBtnCountDown;        //!< counting down
    UIButton                *xpBtnCountDone;        //!< button for done
    UIButton                *xpBtnCountReset;       //!< reset counter
    UIButton                *xpBtnCountRestore;     //!< restore counter
    UIButton                *xpBtnShowInfo;         //!< show info
    UIButton                *xpBtnShowOption;       //!< show option
    UIButton                *xpBtnBell;             //!< button for bell on/off
    
    UILabel                 *xpLblCountTarget;      //!< label for current count
    UILabel					*xpLblCountTotal;		//!< label for total count
    UIProgressView          *xpPbarCountNow;        //!< progress bar for current count

    UIImageView             *xpImageViewCoverDone;  //!< done for PickerCounter
    
/* Model for PickerBook */
    NSFetchedResultsController  *fetchedResultsController; //!< fetch result
    NSManagedObjectContext      *managedObjectContext;     //!< context, created and assigned by AppDelegate

/* AppSetting */
    AppSetting              *mpAppSetting;          //!< app setting
    Book                    *mpReadBook;
    
/* Variables */
    int                      mnCountNow;            //!< count value
    int                      mnCountTarget;         //!< target value
    int                      mnCountTotal;          //!< total count value

/* for PickerCounter */
    NSMutableArray          *mpImageArray;
    int                     manPickerCounterRow[kCounterNumComp];
    UIButton                *mpBtnCountPtr;         //!< current button (Up or Down)

/* sounds */
    AVAudioPlayer           *mpSoundReminder;       //!< play every N times of reads
    AVAudioPlayer           *mpSoundComplete;       //!< play when complete
}

/* accessors */
@property (nonatomic, retain) IBOutlet UIPickerView           *xpPickerBook;
@property (nonatomic, retain) IBOutlet UIPickerView           *xpPickerCounter;
@property (nonatomic, retain) IBOutlet UIButton               *xpBtnCountUp;
@property (nonatomic, retain) IBOutlet UIButton               *xpBtnCountDown;
@property (nonatomic, retain) IBOutlet UIButton               *xpBtnCountDone;
@property (nonatomic, retain) IBOutlet UIButton               *xpBtnCountReset;
@property (nonatomic, retain) IBOutlet UIButton               *xpBtnCountRestore;
@property (nonatomic, retain) IBOutlet UIButton               *xpBtnShowInfo;
@property (nonatomic, retain) IBOutlet UIButton               *xpBtnShowOption;
@property (nonatomic, retain) IBOutlet UIButton               *xpBtnBell;

@property (nonatomic, retain) IBOutlet UILabel                *xpLblCountTarget;
@property (nonatomic, retain) IBOutlet UILabel                *xpLblCountTotal;
@property (nonatomic, retain) IBOutlet UIProgressView         *xpPbarCountNow;

@property (nonatomic, retain) IBOutlet UIImageView            *xpImageViewCoverDone;

@property (nonatomic, retain)          NSFetchedResultsController   *fetchedResultsController;
@property (nonatomic, retain)          NSManagedObjectContext       *managedObjectContext;
@property (nonatomic, retain)          AppSetting                   *mpAppSetting;
@property (nonatomic, assign)          Book                         *mpReadBook;

@property (nonatomic, retain)          AVAudioPlayer           *mpSoundReminder;
@property (nonatomic, retain)          AVAudioPlayer           *mpSoundComplete;

//=============================================================================
// METHODS
//=============================================================================
- (IBAction)onBookList;

- (IBAction)onCountUp;
//- (IBAction)onCountDown;
- (IBAction)onCountReset;
- (IBAction)onCountRestore;
- (IBAction)onShowInfo;
- (IBAction)onShowOption;

- (IBAction)onCountDone;

//=============================================================================
@end
