/*!
 * \file  OptionViewCtrl.h
 *       Implement Option View Controller for BuddhaCounter project
 */
/***************************************************************************/
/* Copyright (c) 2010 AuroraWand LLC                                       */
/* All rights reserved.                                                    */
/*                                                                         */
/* No part of this document may be copied, reproduced,                     */
/* or transmitted in any form without the prior written                    */
/* consent of AuroraWand LLC, San Jose, CA                                 */
/*                                                                         */
/* Created by LinCheng Wang on 05/25/10                                    */
/***************************************************************************/

//=============================================================================
// COMPILATION OPTIONS
//=============================================================================
//#define DEBUG_LEVEL     /* to turn on message utility by UtilMsg.h */

//=============================================================================
// HEADER FILES
//=============================================================================
#import <UIKit/UIKit.h>
#import <CoreData/CoreData.h>

//=============================================================================
// MACROS & INLINE FUNCTIONS
//=============================================================================
typedef enum {
    eOptionFlag_CountingOrder = (1 << 0),
    eOptionFlag_SortingKey    = (1 << 1),
    eOptionFlag_PlaySound     = (1 << 2),
} EOptionFlag;

//=============================================================================
// TYPEDEFS & DATA STRUCTURES
//=============================================================================

//=============================================================================
// CLASS INTERFACE
//=============================================================================
@protocol OptionViewCtrlDelegate;
@class AppSetting;

@interface OptionViewCtrl : UIViewController <NSFetchedResultsControllerDelegate> 
{
    id <OptionViewCtrlDelegate> optionViewCtrlDelegate;

/* data model */
    NSFetchedResultsController  *fetchedResultsController;      //!< fetch result
    NSManagedObjectContext      *managedObjectContext;          //!< context, created and assigned by AppDelegate
    
/* AppSetting */
    AppSetting                  *mpAppSetting;                  //!< app setting

/* user interface */
    UIImageView                 *xpBgView;
    UISegmentedControl          *xpCountingOrder;
    UISegmentedControl          *xpSortingKey;
    UISegmentedControl          *xpPlaySound;
    UIButton                    *xpBtnShowInfo;
    UIButton                    *xpBtnShowFeature;
    UIButton                    *xpBtnShowHelp;
}

@property (nonatomic, assign) id <OptionViewCtrlDelegate> optionViewCtrlDelegate;

/* data model */
@property (nonatomic, retain) NSFetchedResultsController      *fetchedResultsController;
@property (nonatomic, retain) NSManagedObjectContext          *managedObjectContext;

/* AppSetting */
@property (nonatomic, retain)             AppSetting          *mpAppSetting;

/* user interface */
@property (nonatomic, retain) IBOutlet    UIImageView         *xpBgView;
@property (nonatomic, retain) IBOutlet    UISegmentedControl  *xpCountingOrder;
@property (nonatomic, retain) IBOutlet    UISegmentedControl  *xpSortingKey;
@property (nonatomic, retain) IBOutlet    UISegmentedControl  *xpPlaySound;
@property (nonatomic, retain) IBOutlet    UIButton            *xpBtnShowInfo;
@property (nonatomic, retain) IBOutlet    UIButton            *xpBtnShowFeature;
@property (nonatomic, retain) IBOutlet    UIButton            *xpBtnShowHelp;

//=============================================================================
// METHODS
//=============================================================================
- (IBAction)onDone;
- (IBAction)onCountingOrder;
//- (IBAction)onSortingKey;
- (IBAction)onPlaySound;
- (IBAction)onShowInfo:(id)pSender;

//=============================================================================
@end    /* OptionViewCtrl */

//=============================================================================
// PROTOCOL METHODS
//=============================================================================
@protocol OptionViewCtrlDelegate
- (void)optionViewCtrl:(OptionViewCtrl *)pViewCtrl didFinishWithChangeFlag:(int)nChangeFlag;

//=============================================================================
@end    /* OptionViewCtrlDelegate */
